==> feed_plugin-0.0.50.tar.gz: lib/widgets/activities.dart <==
import 'package:feed_plugin/utilities/colors.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_screenutil/screenutil_init.dart';

class BusinessProfilePage extends StatelessWidget {
  List<String> titles = [
    "Calls",
    "Leads",
    "Sales",
    "Messages",
    "Open Issues",
    "Meetings",
  ];

  List<String> subTitles = [
    "You have 150 calls",
    "You have 10 Leads",
    "You have 24 Sales",
    "You have 88 Messages",
    "You have 0 Open Issues",
    "You have 3 Meetings",
  ];
  List<int> colors = [
    0xFF0062FF,
    0xFF50B5FF,
    0xFFA461D8,
    0xFF3DD598,
    0xFFFFC5A5A,
    0xFFFFC542,
  ];
  List<Icon> icons = [
    Icon(
      Icons.local_phone_outlined,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.person_outline,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.monetization_on_outlined,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.mail_outline,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.lock_open,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.date_range_outlined,
      color: Color(0xFF083356),
      size: 30,
    ),
  ];

  @override
  Widget build(BuildContext context) {
    final _screenSize = MediaQuery.of(context).size;
    return ScreenUtilInit(
      builder: () => Scaffold(
        appBar: PreferredSize(
            preferredSize: Size.fromHeight(70.0),
            child: AppBar(
              backgroundColor: Color(0xFF083356),
              actions: <Widget>[
                IconButton(
                    icon: Icon(
                      Icons.person_pin,
                      size: 40,
                    ),
                    onPressed: () {}),
              ],
              title: Padding(
                padding: EdgeInsets.only(top: ScreenUtil().setWidth(10)),
                child: Center(
                    child: Text(
                  "Activities",
                  style: TextStyle(color: Colors.white),
                )),
              ),
            )),
        body: Directionality(
          textDirection: TextDirection.ltr,
          child: ListView.builder(
            itemCount: 6,
            itemBuilder: (context, pos) {
              return ClipRRect(
                borderRadius: BorderRadius.circular(ScreenUtil().setWidth(20)),
                child: Container(
                  margin:
                      EdgeInsets.only(left: 10, top: 5, right: 10, bottom: 5),
                  child: ClipPath(
                      clipper: ShapeBorderClipper(
                          shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.circular(
                                  ScreenUtil().setWidth(17)))),
                      child: Card(
                        elevation: 2,
                        shape: Border(
                            top: BorderSide(
                                color: appLightGreyBg,
                                width: ScreenUtil().setWidth(2)),
                            right: BorderSide(
                                color: appLightGreyBg,
                                width: ScreenUtil().setWidth(2)),
                            left: BorderSide(
                                color: Color(colors[pos]),
                                width: ScreenUtil().setWidth(6))),
                        child: Padding(
                          padding: EdgeInsets.all(ScreenUtil().setWidth(13)),
                          child: ListTile(
                            leading: Container(
                              height: ScreenUtil().setWidth(40),
                              width: ScreenUtil().setWidth(40),
                              child: ClipRRect(
                                borderRadius: BorderRadius.circular(
                                    ScreenUtil().setWidth(8)),
                                child: Container(
                                  color: Color(0xE8ECEFE8ECEF),
                                  child: (icons[pos]),
                                ),
                              ),
                            ),
                            title: Text(
                              titles[pos],
                              overflow: TextOverflow.ellipsis,
                              style: TextStyle(
                                color: Color(colors[pos]),
                                fontWeight: FontWeight.bold,
                                fontSize: ScreenUtil().setSp(20),
                              ),
                            ),
                            subtitle: Padding(
                              padding: EdgeInsets.only(
                                  top: ScreenUtil().setWidth(5)),
                              child: Text(
                                subTitles[pos],
                                style: TextStyle(
                                  color: Color(0xFF083356),
                                ),
                              ),
                            ),
                          ),
                        ),
                      )),
                ),
              );
            },
          ),
        ),
      ),
    );
  }
}

==> feed_plugin-0.1.19.tar.gz: lib/widgets/activities.dart <==
import 'package:feed_plugin/pages/my_feed.dart';
import 'package:feed_plugin/utilities/colors.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_screenutil/screenutil_init.dart';

class BusinessProfilePage extends StatelessWidget {
  BusinessProfilePage({Key key, this.loc}) : super(key: key);

  final loc;
  List<String> titles = [
    "Calls",
    "Leads",
    "Sales",
    "Messages",
    "Open Issues",
    "Meetings",
  ];

  List<String> subTitles = [
    "150",
    "10",
    "24",
    "8",
    "0",
    "3",
  ];
  List<int> colors = [
    0xFF0062FF,
    0xFF50B5FF,
    0xFFA461D8,
    0xFF3DD598,
    0xFFFFC5A5A,
    0xFFFFC542,
  ];
  List<Icon> icons = [
    Icon(
      Icons.local_phone_outlined,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.person_outline,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.monetization_on_outlined,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.mail_outline,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.lock_open,
      color: Color(0xFF083356),
      size: 30,
    ),
    Icon(
      Icons.date_range_outlined,
      color: Color(0xFF083356),
      size: 30,
    ),
  ];

  @override
  Widget build(BuildContext context) {
    // final _screenSize = MediaQuery.of(context).size;
    return ScreenUtilInit(
      builder: () => Scaffold(
        appBar: PreferredSize(
            preferredSize: Size.fromHeight(70.0),
            child: AppBar(
                automaticallyImplyLeading: false,
                backgroundColor: Color(0xFF083356),
                leading: Padding(
                  padding: EdgeInsets.only(),
                  child: IconButton(
                      icon: Icon(
                        Icons.person_pin,
                        size: 40,
                      ),
                      onPressed: () {}),
                ),
                title: Padding(
                  padding: EdgeInsets.only(top: ScreenUtil().setWidth(10)),
                  child: Center(
                      child: Text(
                    loc.translate("Activities"),
                    style: TextStyle(color: Colors.white),
                  )),
                ),
                actions: <Widget>[
                  IconButton(
                      icon: Icon(
                        Icons.arrow_forward,
                      ),
                      onPressed: () {
                        Navigator.pop(
                          context,
                          MyFeedPage(
                            currentUser: null,
                            dislikeId: null,
                            loc: null,
                            likeId: null,
                            pollOptionsList: [],
                            saveId: null,
                            pollVotesList: [],
                            postsList1: [],
                          ),
                        );
                      }),
                ])),
        body: Directionality(
          textDirection: TextDirection.ltr,
          child: ListView.builder(
            itemCount: 6,
            itemBuilder: (context, pos) {
              return ClipRRect(
                borderRadius: BorderRadius.circular(ScreenUtil().setWidth(20)),
                child: Container(
                  margin:
                      EdgeInsets.only(left: 10, top: 5, right: 10, bottom: 5),
                  child: ClipPath(
                      clipper: ShapeBorderClipper(
                          shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.circular(
                                  ScreenUtil().setWidth(17)))),
                      child: Card(
                        elevation: 2,
                        shape: Border(
                            top: BorderSide(
                                color: appLightGreyBg,
                                width: ScreenUtil().setWidth(2)),
                            right: BorderSide(
                                color: appLightGreyBg,
                                width: ScreenUtil().setWidth(2)),
                            left: BorderSide(
                                color: Color(colors[pos]),
                                width: ScreenUtil().setWidth(6))),
                        child: Padding(
                          padding: EdgeInsets.all(ScreenUtil().setWidth(13)),
                          child: ListTile(
                            leading: Container(
                              height: ScreenUtil().setWidth(40),
                              width: ScreenUtil().setWidth(40),
                              child: ClipRRect(
                                borderRadius: BorderRadius.circular(
                                    ScreenUtil().setWidth(8)),
                                child: Container(
                                  color: Color(0xE8ECEFE8ECEF),
                                  child: (icons[pos]),
                                ),
                              ),
                            ),
                            title: Text(
                              loc.translate(titles[pos]),
                              overflow: TextOverflow.ellipsis,
                              style: TextStyle(
                                color: Color(colors[pos]),
                                fontWeight: FontWeight.bold,
                                fontSize: ScreenUtil().setSp(20),
                              ),
                            ),
                            subtitle: Padding(
                              padding: EdgeInsets.only(
                                  top: ScreenUtil().setWidth(5)),
                              child: Text(
                                loc.translate("You have ") +
                                    subTitles[pos] +
                                    (" ") +
                                    loc.translate(titles[pos]),
                                style: TextStyle(
                                  color: Color(0xFF083356),
                                ),
                              ),
                            ),
                          ),
                        ),
                      )),
                ),
              );
            },
          ),
        ),
      ),
    );
  }
}
